AFRL labeling Image Info (sarpy.annotation.afrl_elements.ImageInfo)
===================================================================

.. automodule:: sarpy.annotation.afrl_elements.ImageInfo
    :members:
    :show-inheritance:
    :inherited-members:
